==> content_toggle.1.2.tar.gz: plugins/function.toggle_close.php <==
<?php
#CMS - CMS Made Simple
#(c)2009 by Peter Orije (pedrosken@gmail.com)
#This project's homepage is: http://www.web2do.be
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

function smarty_cms_function_toggle_close($params, &$smarty){

	echo '		</div>
	</div>
	
';
}

function smarty_cms_help_function_toggle_close() {
	?>
	<h3>What does this do?</h3>
	<p>It creates a div (&quot;block&quot;) witch can collapse and expand by pressing the bar, it uses JQuery.<br />
	You can view a demo here : <a href="http://www.web2do.be/webdesign" target="_blank">DEMO</a>
</p>
		<h3>How do I use it?</h3>
<p>Just insert the tag into your content or template like: <code>{toggle_start title="text line for the top bar"}</code><br />
  and close it with <code>{toggle_close}</code><br />
  <br />
  <strong>For example 1:</strong><br />
  <code>
  {toggle_start title=&quot;Web Design &amp; Development&quot;}<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
  {toggle_close}<br /> 
  <br />
</code>
  (this 'll output an closed window from 625 pixels width)
<br />
<br />

  <strong>For example 2:</strong><br />
  <code>
  {toggle_start status=&quot;active&quot; width=&quot;750&quot; title=&quot;Web Design &amp; Development&quot;}<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
  {toggle_close}<br /> 
  <br />
</code>
  (this 'll output an open window from 720 pixels width)



</p>
<h3>The result: </h3>
<img src="../lib/toggle/sample2.gif" /><br />
<br />
For personal changes you can edit the top bar (trigger.gif)
like this example:<br />
<img src="../lib/toggle/sample.gif" /><br />

  
<p>&nbsp;</p>
<h3>Installation:</h3>
<p><u>1) Load Jquery</u><br />
  Make sure &quot;jqeury library is loaded&quot; by inserting this line, unless you already have jquery installed in your head section of your template/shabloon.<br />
<br />
<code>
&lt;script type=&quot;text/javascript&quot; src=&quot;lib/toggle/jquery.js&quot;&gt;&lt;/script&gt;<br />
&lt;/head&gt; </code></p>
<p><u>2) Now for easy use you can edit TinyMCE (not necessary)</u><br />
  goto admin / Extentsions /TinyMce WYSIWYG<br />
open tab Advanced, scroll down and edit &quot;Custom dropdown:&quot;</p>
<p>add this code or change original:<br />
  ---|---<br />
  Start expand/collapse-area|{toggle_start title=\'This is my expandable area\'}<br />
  End expand/collapse-area|{toggle_close}<br />
  ---|---</p>
<p>and save<br />
  now you can use the icon &quot;Specifik Dropdown-menu&quot; in TinyMCE menubar.</p>
<p>&nbsp; </p>
<h3>Parameters</h3>
<ul>
  <li><em>(optional)</em> title=&quot;some text here&quot; - Display title in de bar.</li>
  <li><em>(optional)</em> status=&quot;active&quot; - This 'll show the content, if omitted the content 'll be collapsed by default.</li>
  <li><em>(optional)</em> width=&quot;700&quot; - Controls the width of your content.<br />
		if not set then default width = 625px;<br />
		<span style="color:red;">Warning</span>: when using multiple content togle windows it only needs to be set in the first toggle difenition. Else this settings won't work. </li>
  
</ul>
<p>&nbsp;</p>

done... 
	  <?php
}







function smarty_cms_about_function_toggle_close() {
	?>
      
<p>Author: Peter Orije <a href="http://www.web2do.be">www.web2do.be</a></p>
	<p>Version: 1.1</p>
	<p>Scourse : http://www.sohtanaka.com/web-design/examples/toggle/</p>
	<p>&nbsp;</p>

	<?php
}

?>

==> content_toggle-1.3.tar.gz: plugins/function.toggle_close.php <==
<?php
#CMS - CMS Made Simple
#(c)2009 by Peter Orije (pedrosken@gmail.com)
#This project's homepage is: http://www.web2do.be
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

function smarty_cms_function_toggle_close($params, &$smarty){

	echo '		</div>
	</div>
	
';
}

function smarty_cms_help_function_toggle_close() {
	?>
	<h3>What does this do?</h3>
	<p>It creates a div (&quot;block&quot;) witch can collapse and expand by pressing the bar, it uses JQuery.<br />
	You can view a demo here : <a href="http://www.web2do.be/content_toggle" target="_blank">DEMO</a>
</p>
		<h3>How do I use it?</h3>
<p>Just insert the tag into your content or template like: <code>{toggle_start title="text line for the top bar"}</code><br />
  and close it with <code>{toggle_close}</code><br />
  <br />
  <strong>For example 1:</strong><br />
  <code>
  {toggle_start title=&quot;Web Design &amp; Development&quot;}<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
  {toggle_close}<br /> 
  <br />
</code>
  (this 'll output an closed window from 625 pixels width)
<br />
<br />

  <strong>For example 2:</strong><br />
  <code>
  {toggle_start status=&quot;active&quot; width=&quot;750&quot; title=&quot;Web Design &amp; Development&quot;}<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
  {toggle_close}<br /> 
  <br />
</code>
  (this 'll output an open window from 720 pixels width)



</p>
<h3>The result: </h3>
<img src="../lib/toggle/sample2.gif" /><br />
<br />
For personal changes you can edit the top bar (trigger.gif)
like this example:<br />
<img src="../lib/toggle/sample.gif" /><br />

  
<p>&nbsp;</p>
<h3>Installation:</h3>
<p><u>1) Load Jquery</u><br />
  Make sure &quot;jqeury library is loaded&quot; by inserting this line, unless you already have jquery installed in your head section of your template/shabloon.<br />
<br />
<code>
&lt;script type=&quot;text/javascript&quot; src=&quot;lib/toggle/jquery.js&quot;&gt;&lt;/script&gt;<br />
</code>
<br />
Or use jQuery script from Google:<br /><br />

<code>&lt;script type=&quot;text/javascript&quot; src=&quot;https://ajax.googleapis.com/ajax/libs/jquery/1.4.4/jquery.min.js&quot;&gt;&lt;/script&gt;
</code>


</p>
<p><u>2) Now for easy use you can edit TinyMCE (optional)</u><br />
  goto admin / Extentsions /TinyMce WYSIWYG<br />
open tab Advanced, scroll down and edit &quot;Custom dropdown:&quot;</p>
<p>add this code or change original:<br />
  ---|---<br />
  Start expand/collapse-area|{toggle_start title=\'This is my expandable area\'}<br />
  End expand/collapse-area|{toggle_close}<br />
  ---|---</p>
<p>and save<br />
  now you can use the icon &quot;Specifik Dropdown-menu&quot; in TinyMCE menubar.</p>
<p>&nbsp; </p>
<h3>Parameters</h3>
<ul>
  <li><em>(optional)</em> title=&quot;some text here&quot; - Display title in the bar.</li>
  <li><em>(optional)</em> status=&quot;active&quot; - This 'll show the content, if omitted the content 'll be collapsed by default.</li>
  <li><em>(optional)</em> width=&quot;700&quot; - Controls the width of your content.<br />
		if not set then default width = 625px;<br />
		<span style="color:red;">Warning</span>: when using multiple content toggle windows it only needs to be set in the first toggle difenition. Else this setting won't work. </li>
  
</ul>
<p>&nbsp;</p>

done... 
	  <?php
}







function smarty_cms_about_function_toggle_close() {
	?>
      
      
<p>Author: Peter Orije <a href="http://www.web2do.be">www.web2do.be/content_toggle</a></p>
	<p>Version: 1.3	</p>
   <p>&nbsp;</p>

	<?php
}

?>
